#!/bin/sh

ver=`sed -n -e 's/^.*Revision: //p' /REVISION`
wanted="37956"

if [ "$ver" != "$wanted" ] ; then
    echo "Your firmware version $ver is not compatible with this patch"
    echo "Installation cannot continue"
    echo "This patch requires firmware version simply8654t2_trunk_37956-1_201108211726.bin"
    exit
fi

if [ -e /tmp/3pimp.tgz ] ; then
    :
else
    echo update not found - exiting
    exit
fi

if [ "$(/sbin/setxenv2 -f /dev/sigmblocka -k z.allow_telnet | cut -d' ' -f4)" != "0x00000001" ] ; then
   echo "enabling telnet in the rescue system"
   /sbin/setxenv2 -f /dev/sigmblocka -k z.allow_telnet -v 0x00000001
fi

if [ "$(/sbin/setxenv2 -f /dev/sigmblocka -k z.allow_telnet | cut -d' ' -f4)" != "0x00000001" ] ; then
   echo "enabling telnet in the rescue system"
   /sbin/setxenv2 -f /dev/sigmblocka -k z.allow_telnet -v 0x00000001
fi

echo remounting / rw
/sbin/fsck.jfs /dev/sda5
mount -o remount,rw /dev/sda5 /

echo making backups of system files
mv /etc/rc.d/rcS /etc/rc.d/rcS.orig
cp /etc/passwd /etc/passwd.orig
cp /avtrex/bin/sigma8654_CCESonyMax_backend /avtrex/bin/sigma8654_CCESonyMax_backend.orig
cp /avtrex/bin/sgtv.propbin /avtrex/bin/sgtv.propbin.orig
cp /avtrex/bin/files/argent/avtrex_splash.png /avtrex/bin/files/argent/avtrex_splash.png.orig

echo installing...
cd /
tar -C / -xzf /tmp/3pimp.tgz

echo creating dual boot files
ln -fs /etc/rc.d/rcS.noscan /etc/rc.d/rcS
cd /avtrex/bin/files/argent && ln -fs avtrex_splash-normal.png avtrex_splash.png
cd /tmp
cp /avtrex/bin/sigma8654_CCESonyMax_backend /avtrex/bin/sigma8654_CCESonyMax_backend.noscan
cp /avtrex/bin/sgtv.propbin /avtrex/bin/epg.propbin

echo Applying binary patches
printf "\x20\x75\x6e" | dd of=/avtrex/bin/sigma8654_CCESonyMax_backend.noscan bs=1 seek=20115182 conv=notrunc
printf "\x4e\x6f\x72\x6d\x61\x6c\x20\x6d\x6f\x64\x65\x20\x2d\x20\x70\x72\x65\x73\x73\x20\x70\x6f\x77\x65\x72\x20\x74\x6f\x20\x77\x61\x6b\x65\x20\x75\x70\x20\x74\x68\x65\x20\x50\x56\x52" | dd of=/avtrex/bin/sgtv.propbin bs=1 seek=382551 conv=notrunc
printf "\x4e\x6f\x72\x6d\x61\x6c\x20\x6d\x6f\x64\x65\x20\x2d\x20\x70\x72\x65\x73\x73\x20\x70\x6f\x77\x65\x72\x20\x74\x6f\x20\x77\x61\x6b\x65\x20\x75\x70\x20\x74\x68\x65\x20\x50\x56\x52" | dd of=/avtrex/bin/sgtv.propbin bs=1 seek=1024302 conv=notrunc
printf "\x45\x50\x47\x20\x6d\x6f\x64\x65\x20\x2d\x20\x70\x72\x65\x73\x73\x20\x70\x6f\x77\x65\x72\x20\x74\x6f\x20\x77\x61\x6b\x65\x20\x75\x70\x20\x74\x68\x65\x20\x50\x56\x52\x2e\x2e\x2e" | dd of=/avtrex/bin/epg.propbin bs=1 seek=382551 conv=notrunc
printf "\x45\x50\x47\x20\x6d\x6f\x64\x65\x20\x2d\x20\x70\x72\x65\x73\x73\x20\x70\x6f\x77\x65\x72\x20\x74\x6f\x20\x77\x61\x6b\x65\x20\x75\x70\x20\x74\x68\x65\x20\x50\x56\x52\x2e\x2e\x2e" | dd of=/avtrex/bin/epg.propbin bs=1 seek=1024302 conv=notrunc

echo mounting / ro
echo "if you see an error here, that's OK"
mount -o remount,ro /dev/sda5 /

echo install completed

echo creating intial database backup
rsync -a --no-owner /settings/db/ /home/3view/backup/database

echo creating initial channels backup
/avtrex/bin//ndb_guide_dump_file_5_5 -p -s > /home/3view/backup/channels/channels.txt

echo done

echo update finished, please type reboot now to finish installation.

